<?php
if (!(defined('_VALID_CB') || defined('_JEXEC') || defined('_VALID_MOS')))
{
	die('Direct Access to this location is not allowed.');
}

class getSubscriptionHistoryTab extends cbTabHandler
{
	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->cbTabHandler();
	}

	/**
	 * Display registration history of a user
	 *
	 * @param object $tab
	 * @param JUser  $user
	 * @param int    $ui
	 *
	 * @return string
	 */
	public function getDisplayTab($tab, $user, $ui)
	{
		// Require libraries
		require_once JPATH_ADMINISTRATOR . '/components/com_osmembership/loader.php';

		JLoader::register('OSMembershipModelSubscriptions', JPATH_ROOT . '/components/com_osmembership/model/subscriptions.php');

		/* @var OSMembershipModelSubscriptions $model */
		$model = MPFModel::getInstance('Subscriptions', 'OSMembershipModel', ['remember_states' => false, 'ignore_request' => true]);
		$total = $model->getTotal();

		$params        = $this->params;
		$numberRecords = $params->get('number_records', 10);
		$pagingParams  = $this->_getPaging(array(), array("entries_"));

		if ($pagingParams["entries_limitstart"] === null)
		{
			$pagingParams["entries_limitstart"] = "0";
		}

		if ($numberRecords > $total)
		{
			$pagingParams["entries_limitstart"] = "0";
		}

		$limitStart = $pagingParams["entries_limitstart"] ? $pagingParams["entries_limitstart"] : "0";

		$model->set('limitstart', $limitStart)
			->set('limit', $numberRecords);
		$rows = $model->getData();

		echo JFactory::getDbo()->getQuery();

		if (count($rows))
		{
			ob_start();
			$this->drawSubscriptionsHistory($rows, $pagingParams, $numberRecords, $total);

			return ob_get_clean();
		}
	}

	/**
	 * Draw the output for subscriptions history
	 *
	 * @param array $rows
	 * @param array $pagingParams
	 * @param int   $numberSubscriptions
	 * @param int   $total
	 */
	private function drawSubscriptionsHistory($rows, $pagingParams, $numberSubscriptions, $total)
	{
		$config = OSMembershipHelper::getConfig();
		$Itemid = OSMembershipHelper::getItemid();
		OSMembershipHelper::loadLanguage();
		$bootstrapHelper  = OSMembershipHelperBootstrap::getInstance();
		$centerClass      = $bootstrapHelper->getClassMapping('center');
		$hiddenPhoneClass = $bootstrapHelper->getClassMapping('hidden-phone');
		$cols = 5;
		?>
        <table class="<?php echo $bootstrapHelper->getClassMapping('table table-striped table-bordered') ?>">
            <thead>
            <tr>
                <th>
					<?php echo JText::_('OSM_PLAN') ?>
                </th>
                <th class="<?php echo $centerClass; ?>">
					<?php echo JText::_('OSM_SUBSCRIPTION_DATE'); ?>
                </th>
                <th class="<?php echo $centerClass; ?>">
					<?php echo JText::_('OSM_ACTIVATE_TIME'); ?>
                </th>
                <th style="text-align: right;" class="<?php echo $hiddenPhoneClass; ?>">
					<?php echo JText::_('OSM_GROSS_AMOUNT'); ?>
                </th>
                <th class="<?php echo $hiddenPhoneClass; ?>">
					<?php echo JText::_('OSM_SUBSCRIPTION_STATUS'); ?>
                </th>
				<?php
				if ($config->activate_invoice_feature)
				{
				    $cols++;
				?>
                    <th class="<?php echo $hiddenPhoneClass . ' ' . $centerClass; ?>">
						<?php echo JText::_('OSM_INVOICE_NUMBER'); ?>
                    </th>
				<?php
				}
				?>
            </tr>
            </thead>
            <tbody>
			<?php
			for ($i = 0, $n = count($rows); $i < $n; $i++)
			{
				$row    = $rows[$i];
				$link = JRoute::_('index.php?option=com_osmembership&view=subscription&id=' . $row->id . '&Itemid=' . $Itemid);
				$symbol = $row->currency_symbol ? $row->currency_symbol : $row->currency;
				?>
                <tr>
                    <td>
                        <a href="<?php echo $link; ?>"><?php echo $row->plan_title; ?></a>
                    </td>
                    <td class="<?php echo $centerClass; ?>">
						<?php echo JHtml::_('date', $row->created_date, $this->config->date_format); ?>
                    </td>
                    <td class="<?php echo $centerClass; ?>">
                        <strong><?php echo JHtml::_('date', $row->from_date, $this->config->date_format); ?></strong> <?php echo JText::_('OSM_TO'); ?>
                        <strong>
							<?php
							if ($row->lifetime_membership || $row->to_date == '2099-12-31 23:59:59')
							{
								echo JText::_('OSM_LIFETIME');
							}
							else
							{
								echo JHtml::_('date', $row->to_date, $this->config->date_format);
							}
							?>
                        </strong>
                    </td>
                    <td style="text-align: right;" class="<?php echo $hiddenPhoneClass; ?>">
						<?php echo OSMembershipHelper::formatCurrency($row->gross_amount, $this->config, $symbol) ?>
                    </td>
                    <td class="<?php echo $hiddenPhoneClass; ?>">
						<?php
						switch ($row->published)
						{
							case 0 :
								echo JText::_('OSM_PENDING');
								break;
							case 1 :
								echo JText::_('OSM_ACTIVE');
								break;
							case 2 :
								echo JText::_('OSM_EXPIRED');
								break;
							case 3 :
								echo JText::_('OSM_CANCELLED_PENDING');
								break;
							case 4 :
								echo JText::_('OSM_CANCELLED_REFUNDED');
								break;
						}
						?>
                    </td>
					<?php
					if ($config->activate_invoice_feature)
					{
					?>
                        <td class="<?php echo $hiddenPhoneClass . ' ' . $centerClass; ?>">
							<?php
							if ($row->invoice_number)
							{
							?>
                                <a href="<?php echo JRoute::_('index.php?option=com_osmembership&task=download_invoice&id=' . $row->id); ?>"
                                   title="<?php echo JText::_('OSM_DOWNLOAD'); ?>"><?php echo OSMembershipHelper::formatInvoiceNumber($row, $config); ?></a>
							<?php
							}
							?>
                        </td>
					<?php
					}
					?>
                </tr>
				<?php
			}
			?>
            </tbody>
			<?php
			if ($total > $numberSubscriptions)
			{
			?>
                <tfoot>
                <tr>
                    <td colspan="<?php echo $cols; ?>">
                        <div class="pagination"><?php echo $this->_writePaging($pagingParams, "entries_", $numberSubscriptions, $total); ?></div>
                    </td>
                </tr>
                </tfoot>
			<?php
			}
			?>
        </table>
		<?php
	}
}
